# AUTOGENERATED! DO NOT EDIT! File to edit: ../../../nbs/CLI/utils/transform.ipynb.

# %% auto 0
__all__ = ['de_transform']

# %% ../../../nbs/CLI/utils/transform.ipynb 4
import zarr
from pyproj import Transformer

from .logging import get_logger, log_args
from fastcore.script import call_parse

# %% ../../../nbs/CLI/utils/transform.ipynb 5
@call_parse
@log_args
def de_transform(xx_in, # input x coordinate
                 yy_in, # input y coordinate
                 xx_out, # output x coordinate
                 yy_out, # output y coordinate
                 epsg_in=4326, # input epsg
                 epsg_out=3857, # output epsg
                 log=None, # log file
                ):
    '''Coordinate transformation.
    By default, the input should be longitude (xx_in) and latitude (yy_in) (in degree) and outputs 
    are x (east) and y (south) coordinate in web mercator projection (for plot with google earth map).
    The chunks, shape and dtype of output are same as `xx_in`.
    '''
    xx_in_path = xx_in; yy_in_path = yy_in; xx_out_path = xx_out; yy_out_path = yy_out

    logger = get_logger(logfile=log)
    logger.info(f'input EPSG: {epsg_in}.')
    xx_in_zarr = zarr.open(xx_in_path,'r'); yy_in_zarr = zarr.open(yy_in_path,'r')
    logger.zarr_info('xx_in',xx_in_zarr); logger.zarr_info('yy_in',yy_in_zarr)
    logger.info(f'output EPSG: {epsg_out}.')
    logger.info(f'do the transformation.')
    transformer = Transformer.from_crs(f"EPSG:{epsg_in}", f"EPSG:{epsg_out}",always_xy=True)

    xx_out, yy_out  = transformer.transform(xx_in_zarr[:], yy_in_zarr[:])
    logger.info(f'write output.')
    xx_out_zarr = zarr.open(xx_out_path,'w',shape=xx_in_zarr.shape,dtype=xx_in_zarr.dtype,chunks=xx_in_zarr.chunks)
    yy_out_zarr = zarr.open(yy_out_path,'w',shape=xx_in_zarr.shape,dtype=xx_in_zarr.dtype,chunks=xx_in_zarr.chunks)
    xx_out_zarr[:] = xx_out; yy_out_zarr[:] = yy_out
    logger.info(f'write done.')
